pub fn sequence_effects<T>(
effects: Vec<AnalysisEffect<T>>,
) -> AnalysisEffect<Vec<T>>where
T: Send + 'static,Expand description
Run multiple analysis effects in sequence, collecting results.
This is useful when you need to run a series of analyses that depend on each other or must be run in order.