Module framework_patterns_multi

Module framework_patterns_multi 

Multi-language framework pattern detection.

Extends framework detection to JavaScript, TypeScript, and Python frameworks like React, Express, Django, and FastAPI. Multi-Language Framework Pattern Detection

This module provides comprehensive framework pattern detection across Rust, Python, and JavaScript/TypeScript codebases. It uses TOML configuration to define patterns for various frameworks and provides a unified API for detecting framework-specific code.

Example

use debtmap::analysis::framework_patterns_multi::{FrameworkDetector, Language};

let detector = FrameworkDetector::from_config("framework_patterns.toml")?;
let matches = detector.detect_framework_patterns(&function_ast, &file_context);

Re-exports

pub use detector::FrameworkDetector;
pub use patterns::FrameworkMatch;
pub use patterns::FrameworkPattern as MultiLangFrameworkPattern;
pub use patterns::Language;
pub use patterns::PatternMatcher;

Modules

cli
CLI Framework Pattern Detection
database
Database Framework Pattern Detection
detector
Framework Pattern Detector Implementation
patterns
Framework Pattern Types and Language Support
testing
Testing Framework Pattern Detection
web
Web Framework Pattern Detection