pub fn save_checkpoint(state: &AnalysisState, path: &Path) -> Result<()>Expand description
Save analysis state to checkpoint file.
Creates a JSON checkpoint file that can be used to resume analysis.
pub fn save_checkpoint(state: &AnalysisState, path: &Path) -> Result<()>Save analysis state to checkpoint file.
Creates a JSON checkpoint file that can be used to resume analysis.