log_timing_effect

Function log_timing_effect 

pub fn log_timing_effect(message: String) -> AnalysisEffect<()>
Log a timing diagnostic message via the effect system.

This function provides pure I/O separation for timing diagnostics by checking the DEBTMAP_TIMING environment variable and conditionally outputting timing information to stderr.

Arguments

  • message - The timing message to log

Example

use debtmap::analyzers::effects::log_timing_effect;

let effect = log_timing_effect(format!("[TIMING] parse {}: {:.2}s", path, duration));
effect.run(&env).await?;