pub struct ContextRuleEngine { /* private fields */ }Expand description
Context-aware rules engine
Implementations
Sourceimpl ContextRuleEngine
impl ContextRuleEngine
Sourcepub fn add_rule(&mut self, rule: ContextRule)
pub fn add_rule(&mut self, rule: ContextRule)
Add a custom rule
Sourcepub fn evaluate(
&mut self,
pattern: &DebtPattern,
context: &FunctionContext,
) -> RuleAction
pub fn evaluate( &mut self, pattern: &DebtPattern, context: &FunctionContext, ) -> RuleAction
Evaluate a debt pattern in a given context
Sourcepub fn get_reason(
&self,
pattern: &DebtPattern,
context: &FunctionContext,
) -> Option<String>
pub fn get_reason( &self, pattern: &DebtPattern, context: &FunctionContext, ) -> Option<String>
Get the reason for a rule action
Sourcepub fn should_analyze(
&mut self,
debt_type: &DebtType,
context: &FunctionContext,
) -> bool
pub fn should_analyze( &mut self, debt_type: &DebtType, context: &FunctionContext, ) -> bool
Check if a debt type should be analyzed in a context
Sourcepub fn get_severity_adjustment(
&mut self,
debt_type: &DebtType,
context: &FunctionContext,
) -> i32
pub fn get_severity_adjustment( &mut self, debt_type: &DebtType, context: &FunctionContext, ) -> i32
Get severity adjustment for a debt type in a context