pub struct CriticalComplexity { /* private fields */ }Expand description
Predicate for critical complexity (both cyclomatic AND cognitive exceed thresholds).
This represents functions that are both hard to test AND hard to understand, indicating the highest priority for refactoring.
Implementations
Sourceimpl CriticalComplexity
impl CriticalComplexity
Sourcepub fn new(cyclomatic_threshold: u32, cognitive_threshold: u32) -> Self
pub fn new(cyclomatic_threshold: u32, cognitive_threshold: u32) -> Self
Create a new predicate with the given thresholds.
Sourcepub fn from_rules(rules: &ValidationRuleSet) -> Self
pub fn from_rules(rules: &ValidationRuleSet) -> Self
Create from a ValidationRuleSet using the critical threshold.
Sourcepub fn description(&self) -> String
pub fn description(&self) -> String
Get a description of what this predicate checks.