pub struct HighCognitive { /* private fields */ }Expand description
Predicate for high cognitive complexity.
Cognitive complexity measures how difficult code is to understand. High values suggest the code should be refactored for readability.
Implementations
Sourceimpl HighCognitive
impl HighCognitive
Sourcepub fn from_rules(rules: &ValidationRuleSet) -> Self
pub fn from_rules(rules: &ValidationRuleSet) -> Self
Create from a ValidationRuleSet using the warning threshold.
Sourcepub fn description(&self) -> String
pub fn description(&self) -> String
Get a description of what this predicate checks.