pub struct LowCoverage { /* private fields */ }Expand description
Predicate for low test coverage.
Functions with low coverage are riskier to modify because bugs may not be caught.
Implementations
Sourceimpl LowCoverage
impl LowCoverage
Sourcepub fn new(threshold: f64) -> Self
pub fn new(threshold: f64) -> Self
Create a new predicate with the given threshold (0.0 to 1.0).
Sourcepub fn from_percentage(percentage: u32) -> Self
pub fn from_percentage(percentage: u32) -> Self
Create with a percentage threshold (0 to 100).
Sourcepub fn description(&self) -> String
pub fn description(&self) -> String
Get a description of what this predicate checks.