pub struct CoverageData { /* private fields */ }Expand description
Coverage data container.
This is a simplified representation of coverage data that can be queried for file-level and function-level coverage.
Implementations
Sourceimpl CoverageData
impl CoverageData
Sourcepub fn get_file_coverage(&self, path: &Path) -> Option<f64>
pub fn get_file_coverage(&self, path: &Path) -> Option<f64>
Get coverage percentage for a file (0.0 to 100.0).
Sourcepub fn get_function_coverage(
&self,
file_path: &Path,
start_line: usize,
end_line: usize,
) -> Option<f64>
pub fn get_function_coverage( &self, file_path: &Path, start_line: usize, end_line: usize, ) -> Option<f64>
Get coverage percentage for a function by line range.
Sourcepub fn add_file_coverage(&mut self, path: PathBuf, coverage: FileCoverage)
pub fn add_file_coverage(&mut self, path: PathBuf, coverage: FileCoverage)
Add coverage data for a file.