pub fn get_current_context() -> AnalysisContextExpand description
Get the current context snapshot.
Called by the panic hook to include context in crash reports.
pub fn get_current_context() -> AnalysisContextGet the current context snapshot.
Called by the panic hook to include context in crash reports.