pub struct GodObjectDetector { /* private fields */ }Expand description
God object detector that orchestrates analysis.
Usage
For primary god object detection, use the extraction adapter instead:
ⓘ
use crate::extraction::adapters::god_object::analyze_god_objects;
let results = analyze_god_objects(&path, &extracted_data);This struct is retained for:
- Threshold configuration
OrganizationDetectortrait implementation (used byrust.rs)
Implementations
Sourceimpl GodObjectDetector
impl GodObjectDetector
Sourcepub fn with_source_content(source_content: &str) -> Self
pub fn with_source_content(source_content: &str) -> Self
Create a detector with source content for enhanced analysis.
Sourcepub fn max_methods(&self) -> usize
pub fn max_methods(&self) -> usize
Get the max_methods threshold configured for this detector.
Sourcepub fn max_fields(&self) -> usize
pub fn max_fields(&self) -> usize
Get the max_fields threshold configured for this detector.
Sourcepub fn max_responsibilities(&self) -> usize
pub fn max_responsibilities(&self) -> usize
Get the max_responsibilities threshold configured for this detector.
Sourcepub fn classify_god_object_impact(
method_count: usize,
field_count: usize,
) -> MaintainabilityImpact
pub fn classify_god_object_impact( method_count: usize, field_count: usize, ) -> MaintainabilityImpact
Classify maintainability impact based on method and field counts.
Pure function that maps god object metrics to impact severity.