pub fn validate_paths_exist(
paths: &[PathBuf],
) -> AnalysisValidation<Vec<PathBuf>>Expand description
Validate that paths exist, accumulating all path errors.
This is useful for validating CLI arguments where multiple paths are provided and we want to report all missing paths at once.