pub fn errors_to_anyhow(errors: Vec<AnalysisError>) -> ErrorExpand description
Convert a list of AnalysisErrors to an anyhow::Error with formatted message.
This is useful when you need to convert accumulated validation errors back to anyhow for backwards compatibility with existing code.