pub struct LocCounter { /* private fields */ }Expand description
Counts lines of code using a consistent methodology across all analysis modes.
Line Counting Rules
- Physical Lines: Raw line count from file
- Code Lines: Lines containing executable code (excludes comments, blanks)
- Comment Lines: Lines that are primarily comments
- Blank Lines: Lines containing only whitespace
File Filtering
Files are excluded if they match:
- Test file patterns:
*_test.rs,tests/**/* - Generated file markers:
@generated,DO NOT EDIT - Custom exclusion patterns from config
Examples
use debtmap::metrics::loc_counter::LocCounter;
use std::path::Path;
let counter = LocCounter::default();
let count = counter.count_file(Path::new("src/lib.rs")).unwrap();
println!("Code lines: {}", count.code_lines);Implementations
Sourceimpl LocCounter
impl LocCounter
Sourcepub fn new(config: LocCountingConfig) -> Self
pub fn new(config: LocCountingConfig) -> Self
Create a new LOC counter with custom configuration
Sourcepub fn count_file(&self, path: &Path) -> Result<LocCount, Error>
pub fn count_file(&self, path: &Path) -> Result<LocCount, Error>
Count lines in a single file with auto-detected language (Spec 201)
Sourcepub fn count_content(&self, content: &str) -> LocCount
pub fn count_content(&self, content: &str) -> LocCount
Count lines in file content (pure function) - backward compatible
Uses conservative comment detection (Unknown language).
For accurate counting, use count_content_with_language instead.
Sourcepub fn count_content_with_language(
&self,
content: &str,
language: Option<LocLanguage>,
) -> LocCount
pub fn count_content_with_language( &self, content: &str, language: Option<LocLanguage>, ) -> LocCount
Count lines in file content with language-aware comment detection (Spec 201)
This method correctly handles:
- Multi-line block comments (
/* ... */) - Nested block comments in Rust
- Rust attributes (
#[...]) as code, not comments - Python
#comments
Sourcepub fn should_include(&self, path: &Path) -> bool
pub fn should_include(&self, path: &Path) -> bool
Determine if file should be included in LOC count
Sourcepub fn is_test_file(&self, path: &Path) -> bool
pub fn is_test_file(&self, path: &Path) -> bool
Check if path is a test file
Sourcepub fn is_generated(&self, path: &Path) -> bool
pub fn is_generated(&self, path: &Path) -> bool
Check if path is a generated file
Sourcepub fn count_from_file_paths(&self, files: &[PathBuf]) -> ProjectLocCount
pub fn count_from_file_paths(&self, files: &[PathBuf]) -> ProjectLocCount
Count LOC for an entire project from file metrics
This ensures each file is counted exactly once by using a HashMap to track unique files.